@@ -26,9 +26,25 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) {
 
   sub test3 :Chained(root) Args(0) {
     my ($self, $c) = @_;
-    $c->view->http_ok;
+    $c->view->http_bad_request;
   }
 
+  sub test4 :Chained(root) Args(0) {
+    my ($self, $c) = @_;
+    $c->view->set_http_ok;
+    $c->res->body($c->view->get_rendered);
+  }
+
+  sub test5 :Chained(root) Args(0) {
+    my ($self, $c) = @_;
+    $c->view->http_created(location=>"abc");
+  }
+
+  sub test6 :Chained(root) Args(0) {
+    my ($self, $c) = @_;
+    $c->view->set_http_created(location=>"abc");
+    $c->res->body($c->view->get_rendered);
+  }
 
 __PACKAGE__->config(namespace=>'');
 __PACKAGE__->meta->make_immutable;
